@@ -3,21 +3,17 @@ package main
 import (
 	"errors"
 	"fmt"
-	"os"
-	"path/filepath"
+	"io"
 	"runtime"
 
 	"github.com/lima-vm/lima/pkg/networks"
+	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 )
 
+const networksURL = "https://lima-vm.io/docs/config/network/#socket_vmnet"
+
 func newSudoersCommand() *cobra.Command {
-	networksMD := "$PREFIX/share/doc/lima/docs/network.md"
-	if exe, err := os.Executable(); err == nil {
-		binDir := filepath.Dir(exe)
-		prefixDir := filepath.Dir(binDir)
-		networksMD = filepath.Join(prefixDir, "share/doc/lima/docs/network.md")
-	}
 	sudoersCommand := &cobra.Command{
 		Use: "sudoers [--check [SUDOERSFILE-TO-CHECK]]",
 		Example: `
@@ -31,14 +27,14 @@ $ limactl sudoers --check /etc/sudoers.d/lima
 		Long: fmt.Sprintf(`Generate the content of the /etc/sudoers.d/lima file for enabling vmnet.framework support.
 The content is written to stdout, NOT to the file.
 This command must not run as the root user.
-See %s for the usage.`, networksMD),
+See %s for the usage.`, networksURL),
 		Args:    WrapArgsError(cobra.MaximumNArgs(1)),
 		RunE:    sudoersAction,
 		GroupID: advancedCommand,
 	}
-	configFile, _ := networks.ConfigFile()
+	cfgFile, _ := networks.ConfigFile()
 	sudoersCommand.Flags().Bool("check", false,
-		fmt.Sprintf("check that the sudoers file is up-to-date with %q", configFile))
+		fmt.Sprintf("check that the sudoers file is up-to-date with %q", cfgFile))
 	return sudoersCommand
 }
 
@@ -46,12 +42,21 @@ func sudoersAction(cmd *cobra.Command, args []string) error {
 	if runtime.GOOS != "darwin" {
 		return errors.New("sudoers command is only supported on macOS right now")
 	}
+	nwCfg, err := networks.LoadConfig()
+	if err != nil {
+		return err
+	}
+	// Make sure the current network configuration is secure
+	if err := nwCfg.Validate(); err != nil {
+		logrus.Infof("Please check %s for more information.", networksURL)
+		return err
+	}
 	check, err := cmd.Flags().GetBool("check")
 	if err != nil {
 		return err
 	}
 	if check {
-		return verifySudoAccess(args)
+		return verifySudoAccess(nwCfg, args, cmd.OutOrStdout())
 	}
 	switch len(args) {
 	case 0:
@@ -65,34 +70,27 @@ func sudoersAction(cmd *cobra.Command, args []string) error {
 	if err != nil {
 		return err
 	}
-	fmt.Print(sudoers)
+	fmt.Fprint(cmd.OutOrStdout(), sudoers)
 	return nil
 }
 
-func verifySudoAccess(args []string) error {
-	config, err := networks.Config()
-	if err != nil {
-		return err
-	}
-	if err := config.Validate(); err != nil {
-		return err
-	}
+func verifySudoAccess(nwCfg networks.Config, args []string, stdout io.Writer) error {
 	var file string
 	switch len(args) {
 	case 0:
-		file = config.Paths.Sudoers
+		file = nwCfg.Paths.Sudoers
 		if file == "" {
-			configFile, _ := networks.ConfigFile()
-			return fmt.Errorf("no sudoers file defined in %q", configFile)
+			cfgFile, _ := networks.ConfigFile()
+			return fmt.Errorf("no sudoers file defined in %q", cfgFile)
 		}
 	case 1:
 		file = args[0]
 	default:
 		return errors.New("can check only a single sudoers file")
 	}
-	if err := config.VerifySudoAccess(file); err != nil {
+	if err := nwCfg.VerifySudoAccess(file); err != nil {
 		return err
 	}
-	fmt.Printf("%q is up-to-date (or sudo doesn't require a password)\n", file)
+	fmt.Fprintf(stdout, "%q is up-to-date (or sudo doesn't require a password)\n", file)
 	return nil
 }
