@@ -35,6 +35,7 @@ type Containerd struct {
 type Network struct {
 	MACAddress string
 	Interface  string
+	Metric     uint32
 }
 type Mount struct {
 	Tag        string
@@ -53,11 +54,14 @@ type Disk struct {
 	FSArgs []string
 }
 type TemplateArgs struct {
+	Debug                           bool
 	Name                            string // instance name
+	Hostname                        string // instance hostname
 	IID                             string // instance id
 	User                            string // user name
+	Comment                         string // user information
 	Home                            string // home directory
-	UID                             int
+	UID                             uint32
 	SSHPubKeys                      []string
 	Mounts                          []Mount
 	MountType                       string
@@ -73,6 +77,8 @@ type TemplateArgs struct {
 	UDPDNSLocalPort                 int
 	TCPDNSLocalPort                 int
 	Env                             map[string]string
+	Param                           map[string]string
+	BootScripts                     bool
 	DNSAddresses                    []string
 	CACerts                         CACerts
 	HostHomeMountPoint              string
@@ -87,13 +93,12 @@ type TemplateArgs struct {
 	TimeZone                        string
 }
 
-func ValidateTemplateArgs(args TemplateArgs) error {
+func ValidateTemplateArgs(args *TemplateArgs) error {
 	if err := identifiers.Validate(args.Name); err != nil {
 		return err
 	}
-	if err := identifiers.Validate(args.User); err != nil {
-		return err
-	}
+	// args.User is intentionally not validated here; the user can override with any name they want
+	// limayaml.FillDefault will validate the default (local) username, but not an explicit setting
 	if args.User == "root" {
 		return errors.New("field User must not be \"root\"")
 	}
@@ -112,13 +117,24 @@ func ValidateTemplateArgs(args TemplateArgs) error {
 			return fmt.Errorf("field mounts[%d] must be absolute, got %q", i, f)
 		}
 	}
-	if args.CACerts.RemoveDefaults == nil {
-		return errors.New("field CACerts.RemoveDefaults must be set")
-	}
 	return nil
 }
 
-func ExecuteTemplate(args TemplateArgs) ([]iso9660util.Entry, error) {
+func ExecuteTemplateCloudConfig(args *TemplateArgs) ([]byte, error) {
+	if err := ValidateTemplateArgs(args); err != nil {
+		return nil, err
+	}
+
+	userData, err := templateFS.ReadFile(path.Join(templateFSRoot, "user-data"))
+	if err != nil {
+		return nil, err
+	}
+
+	cloudConfigYaml := string(userData)
+	return textutil.ExecuteTemplate(cloudConfigYaml, args)
+}
+
+func ExecuteTemplateCIDataISO(args *TemplateArgs) ([]iso9660util.Entry, error) {
 	if err := ValidateTemplateArgs(args); err != nil {
 		return nil, err
 	}
