@@ -13,12 +13,14 @@ import (
 	"path"
 	"path/filepath"
 	"strings"
+	"sync/atomic"
 	"time"
 
 	"github.com/cheggaaa/pb/v3"
 	"github.com/containerd/continuity/fs"
 	"github.com/lima-vm/lima/pkg/httpclientutil"
 	"github.com/lima-vm/lima/pkg/localpathutil"
+	"github.com/lima-vm/lima/pkg/lockutil"
 	"github.com/lima-vm/lima/pkg/progressbar"
 	"github.com/opencontainers/go-digest"
 	"github.com/sirupsen/logrus"
@@ -29,8 +31,7 @@ var HideProgress bool
 
 // hideBar is used only for testing.
 func hideBar(bar *pb.ProgressBar) {
-	bar.Set(pb.ReturnSymbol, "")
-	bar.SetTemplateString("")
+	bar.Set(pb.Static, true)
 }
 
 type Status = string
@@ -230,6 +231,7 @@ func Download(ctx context.Context, local, remote string, opts ...Opt) (*Result,
 	}
 	if _, err := os.Stat(shadData); err == nil {
 		logrus.Debugf("file %q is cached as %q", localPath, shadData)
+		useCache := true
 		if _, err := os.Stat(shadDigest); err == nil {
 			logrus.Debugf("Comparing digest %q with the cached digest file %q, not computing the actual digest of %q",
 				o.expectedDigest, shadDigest, shadData)
@@ -240,41 +242,47 @@ func Download(ctx context.Context, local, remote string, opts ...Opt) (*Result,
 				return nil, err
 			}
 		} else {
-			if err := copyLocal(ctx, localPath, shadData, ext, o.decompress, o.description, o.expectedDigest); err != nil {
-				return nil, err
+			if match, lmCached, lmRemote, err := matchLastModified(ctx, shadTime, remote); err != nil {
+				logrus.WithError(err).Info("Failed to retrieve last-modified for cached digest-less image; using cached image.")
+			} else if match {
+				if err := copyLocal(ctx, localPath, shadData, ext, o.decompress, o.description, o.expectedDigest); err != nil {
+					return nil, err
+				}
+			} else {
+				logrus.Infof("Re-downloading digest-less image: last-modified mismatch (cached: %q, remote: %q)", lmCached, lmRemote)
+				useCache = false
 			}
 		}
-		res := &Result{
-			Status:          StatusUsedCache,
-			CachePath:       shadData,
-			LastModified:    readTime(shadTime),
-			ContentType:     readFile(shadType),
-			ValidatedDigest: o.expectedDigest != "",
+		if useCache {
+			res := &Result{
+				Status:          StatusUsedCache,
+				CachePath:       shadData,
+				LastModified:    readTime(shadTime),
+				ContentType:     readFile(shadType),
+				ValidatedDigest: o.expectedDigest != "",
+			}
+			return res, nil
 		}
-		return res, nil
-	}
-	if err := os.RemoveAll(shad); err != nil {
-		return nil, err
 	}
 	if err := os.MkdirAll(shad, 0o700); err != nil {
 		return nil, err
 	}
 	shadURL := filepath.Join(shad, "url")
-	if err := os.WriteFile(shadURL, []byte(remote), 0o644); err != nil {
+	if err := writeFirst(shadURL, []byte(remote), 0o644); err != nil {
 		return nil, err
 	}
 	if err := downloadHTTP(ctx, shadData, shadTime, shadType, remote, o.description, o.expectedDigest); err != nil {
 		return nil, err
 	}
+	if shadDigest != "" && o.expectedDigest != "" {
+		if err := writeFirst(shadDigest, []byte(o.expectedDigest.String()), 0o644); err != nil {
+			return nil, err
+		}
+	}
 	// no need to pass the digest to copyLocal(), as we already verified the digest
 	if err := copyLocal(ctx, localPath, shadData, ext, o.decompress, "", ""); err != nil {
 		return nil, err
 	}
-	if shadDigest != "" && o.expectedDigest != "" {
-		if err := os.WriteFile(shadDigest, []byte(o.expectedDigest.String()), 0o644); err != nil {
-			return nil, err
-		}
-	}
 	res := &Result{
 		Status:          StatusDownloaded,
 		CachePath:       shadData,
@@ -341,7 +349,7 @@ func Cached(remote string, opts ...Opt) (*Result, error) {
 //   - "time" file contains the time (Last-Modified header)
 //   - "type" file contains the type (Content-Type header)
 func cacheDirectoryPath(cacheDir, remote string) string {
-	return filepath.Join(cacheDir, "download", "by-url-sha256", fmt.Sprintf("%x", sha256.Sum256([]byte(remote))))
+	return filepath.Join(cacheDir, "download", "by-url-sha256", CacheKey(remote))
 }
 
 // cacheDigestPath returns the cache digest file path.
@@ -409,6 +417,10 @@ func copyLocal(ctx context.Context, dst, src, ext string, decompress bool, descr
 		if command != "" {
 			return decompressLocal(ctx, command, dstPath, srcPath, ext, description)
 		}
+		commandByMagic := decompressorByMagic(srcPath)
+		if commandByMagic != "" {
+			return decompressLocal(ctx, commandByMagic, dstPath, srcPath, ext, description)
+		}
 	}
 	// TODO: progress bar for copy
 	return fs.CopyFile(dstPath, srcPath)
@@ -429,6 +441,34 @@ func decompressor(ext string) string {
 	}
 }
 
+func decompressorByMagic(file string) string {
+	f, err := os.Open(file)
+	if err != nil {
+		return ""
+	}
+	defer f.Close()
+	header := make([]byte, 6)
+	if _, err := f.Read(header); err != nil {
+		return ""
+	}
+	if _, err := f.Seek(0, io.SeekStart); err != nil {
+		return ""
+	}
+	if bytes.HasPrefix(header, []byte{0x1f, 0x8b}) {
+		return "gzip"
+	}
+	if bytes.HasPrefix(header, []byte{0x42, 0x5a}) {
+		return "bzip2"
+	}
+	if bytes.HasPrefix(header, []byte{0xfd, 0x37, 0x7a, 0x58, 0x5a, 0x00}) {
+		return "xz"
+	}
+	if bytes.HasPrefix(header, []byte{0x28, 0xb5, 0x2f, 0xfd}) {
+		return "zstd"
+	}
+	return ""
+}
+
 func decompressLocal(ctx context.Context, decompressCmd, dst, src, ext, description string) error {
 	logrus.Infof("decompressing %s with %v", ext, decompressCmd)
 
@@ -517,20 +557,48 @@ func validateLocalFileDigest(localPath string, expectedDigest digest.Digest) err
 	return nil
 }
 
+// mathLastModified takes params:
+//   - ctx: context for calling httpclientutil.Head
+//   - lastModifiedPath: path of the cached last-modified time file
+//   - url: URL to fetch the last-modified time
+//
+// returns:
+//   - matched: whether the last-modified time matches
+//   - lmCached: last-modified time string from the lastModifiedPath
+//   - lmRemote: last-modified time string from the URL
+//   - err: error if fetching the last-modified time from the URL fails
+func matchLastModified(ctx context.Context, lastModifiedPath, url string) (matched bool, lmCached, lmRemote string, err error) {
+	lmCached = readFile(lastModifiedPath)
+	if lmCached == "" {
+		return false, "<not cached>", "<not checked>", nil
+	}
+	resp, err := httpclientutil.Head(ctx, http.DefaultClient, url)
+	if err != nil {
+		return false, lmCached, "<failed to fetch remote>", err
+	}
+	defer resp.Body.Close()
+	lmRemote = resp.Header.Get("Last-Modified")
+	if lmRemote == "" {
+		return false, lmCached, "<missing Last-Modified header>", nil
+	}
+	lmCachedTime, errParsingCachedTime := time.Parse(http.TimeFormat, lmCached)
+	lmRemoteTime, errParsingRemoteTime := time.Parse(http.TimeFormat, lmRemote)
+	if errParsingCachedTime != nil && errParsingRemoteTime != nil {
+		// both time strings are failed to parse, so compare them as strings
+		return lmCached == lmRemote, lmCached, lmRemote, nil
+	} else if errParsingCachedTime == nil && errParsingRemoteTime == nil {
+		// both time strings are successfully parsed, so compare them as times
+		return lmRemoteTime.Equal(lmCachedTime), lmCached, lmRemote, nil
+	}
+	// ignore parsing errors for either time string and assume they are different
+	return false, lmCached, lmRemote, nil
+}
+
 func downloadHTTP(ctx context.Context, localPath, lastModified, contentType, url, description string, expectedDigest digest.Digest) error {
 	if localPath == "" {
 		return fmt.Errorf("downloadHTTP: got empty localPath")
 	}
 	logrus.Debugf("downloading %q into %q", url, localPath)
-	localPathTmp := localPath + ".tmp"
-	if err := os.RemoveAll(localPathTmp); err != nil {
-		return err
-	}
-	fileWriter, err := os.Create(localPathTmp)
-	if err != nil {
-		return err
-	}
-	defer fileWriter.Close()
 
 	resp, err := httpclientutil.Get(ctx, http.DefaultClient, url)
 	if err != nil {
@@ -538,13 +606,13 @@ func downloadHTTP(ctx context.Context, localPath, lastModified, contentType, url
 	}
 	if lastModified != "" {
 		lm := resp.Header.Get("Last-Modified")
-		if err := os.WriteFile(lastModified, []byte(lm), 0o644); err != nil {
+		if err := writeFirst(lastModified, []byte(lm), 0o644); err != nil {
 			return err
 		}
 	}
 	if contentType != "" {
 		ct := resp.Header.Get("Content-Type")
-		if err := os.WriteFile(contentType, []byte(ct), 0o644); err != nil {
+		if err := writeFirst(contentType, []byte(ct), 0o644); err != nil {
 			return err
 		}
 	}
@@ -557,6 +625,14 @@ func downloadHTTP(ctx context.Context, localPath, lastModified, contentType, url
 		hideBar(bar)
 	}
 
+	localPathTmp := perProcessTempfile(localPath)
+	fileWriter, err := os.Create(localPathTmp)
+	if err != nil {
+		return err
+	}
+	defer fileWriter.Close()
+	defer os.RemoveAll(localPathTmp)
+
 	writers := []io.Writer{fileWriter}
 	var digester digest.Digester
 	if expectedDigest != "" {
@@ -596,8 +672,94 @@ func downloadHTTP(ctx context.Context, localPath, lastModified, contentType, url
 	if err := fileWriter.Close(); err != nil {
 		return err
 	}
-	if err := os.RemoveAll(localPath); err != nil {
-		return err
+
+	// If localPath was created by a parallel download keep it. Replacing it
+	// while another process is copying it to the destination may fail the
+	// clonefile syscall. We use a lock to ensure that only one process updates
+	// data, and when we return data file exists.
+
+	return lockutil.WithDirLock(filepath.Dir(localPath), func() error {
+		if _, err := os.Stat(localPath); err == nil {
+			return nil
+		} else if !errors.Is(err, os.ErrNotExist) {
+			return err
+		}
+		return os.Rename(localPathTmp, localPath)
+	})
+}
+
+var tempfileCount atomic.Uint64
+
+// To allow parallel download we use a per-process unique suffix for temporary
+// files. Renaming the temporary file to the final file is safe without
+// synchronization on posix.
+// To make it easy to test we also include a counter ensuring that each
+// temporary file is unique in the same process.
+// https://github.com/lima-vm/lima/issues/2722
+func perProcessTempfile(path string) string {
+	return fmt.Sprintf("%s.tmp.%d.%d", path, os.Getpid(), tempfileCount.Add(1))
+}
+
+// writeFirst writes data to path unless path already exists.
+func writeFirst(path string, data []byte, perm os.FileMode) error {
+	return lockutil.WithDirLock(filepath.Dir(path), func() error {
+		if _, err := os.Stat(path); err == nil {
+			return nil
+		} else if !errors.Is(err, os.ErrNotExist) {
+			return err
+		}
+		return os.WriteFile(path, data, perm)
+	})
+}
+
+// CacheEntries returns a map of cache entries.
+// The key is the SHA256 of the URL.
+// The value is the path to the cache entry.
+func CacheEntries(opt ...Opt) (map[string]string, error) {
+	entries := make(map[string]string)
+	var o options
+	for _, f := range opt {
+		if err := f(&o); err != nil {
+			return nil, err
+		}
 	}
-	return os.Rename(localPathTmp, localPath)
+	if o.cacheDir == "" {
+		return entries, nil
+	}
+	downloadDir := filepath.Join(o.cacheDir, "download", "by-url-sha256")
+	_, err := os.Stat(downloadDir)
+	if err != nil {
+		if errors.Is(err, os.ErrNotExist) {
+			return entries, nil
+		}
+		return nil, err
+	}
+	cacheEntries, err := os.ReadDir(downloadDir)
+	if err != nil {
+		return nil, err
+	}
+	for _, entry := range cacheEntries {
+		entries[entry.Name()] = filepath.Join(downloadDir, entry.Name())
+	}
+	return entries, nil
+}
+
+// CacheKey returns the key for a cache entry of the remote URL.
+func CacheKey(remote string) string {
+	return fmt.Sprintf("%x", sha256.Sum256([]byte(remote)))
+}
+
+// RemoveAllCacheDir removes the cache directory.
+func RemoveAllCacheDir(opt ...Opt) error {
+	var o options
+	for _, f := range opt {
+		if err := f(&o); err != nil {
+			return err
+		}
+	}
+	if o.cacheDir == "" {
+		return nil
+	}
+	logrus.Infof("Pruning %q", o.cacheDir)
+	return os.RemoveAll(o.cacheDir)
 }
