@@ -8,6 +8,7 @@ import (
 	"os/exec"
 	"path/filepath"
 	"runtime"
+	"slices"
 	"strings"
 	"testing"
 	"time"
@@ -18,9 +19,23 @@ import (
 
 func TestMain(m *testing.M) {
 	HideProgress = true
-	os.Exit(m.Run())
+	m.Run()
 }
 
+type downloadResult struct {
+	r   *Result
+	err error
+}
+
+// We expect only few parallel downloads. Testing with larger number to find
+// races quicker. 20 parallel downloads take about 120 milliseconds on M1 Pro.
+const parallelDownloads = 20
+
+// When downloading in parallel usually all downloads completed with
+// StatusDownload, but some may be delayed and find the data file when they
+// start. Can be reproduced locally using 100 parallel downloads.
+var parallelStatus = []Status{StatusDownloaded, StatusUsedCache}
+
 func TestDownloadRemote(t *testing.T) {
 	ts := httptest.NewServer(http.FileServer(http.Dir("testdata")))
 	t.Cleanup(ts.Close)
@@ -57,38 +72,90 @@ func TestDownloadRemote(t *testing.T) {
 		})
 	})
 	t.Run("with cache", func(t *testing.T) {
-		cacheDir := filepath.Join(t.TempDir(), "cache")
-		localPath := filepath.Join(t.TempDir(), t.Name())
-		r, err := Download(context.Background(), localPath, dummyRemoteFileURL, WithExpectedDigest(dummyRemoteFileDigest), WithCacheDir(cacheDir))
-		assert.NilError(t, err)
-		assert.Equal(t, StatusDownloaded, r.Status)
+		t.Run("serial", func(t *testing.T) {
+			cacheDir := filepath.Join(t.TempDir(), "cache")
+			localPath := filepath.Join(t.TempDir(), t.Name())
+			r, err := Download(context.Background(), localPath, dummyRemoteFileURL,
+				WithExpectedDigest(dummyRemoteFileDigest), WithCacheDir(cacheDir))
+			assert.NilError(t, err)
+			assert.Equal(t, StatusDownloaded, r.Status)
 
-		r, err = Download(context.Background(), localPath, dummyRemoteFileURL, WithExpectedDigest(dummyRemoteFileDigest), WithCacheDir(cacheDir))
-		assert.NilError(t, err)
-		assert.Equal(t, StatusSkipped, r.Status)
+			r, err = Download(context.Background(), localPath, dummyRemoteFileURL,
+				WithExpectedDigest(dummyRemoteFileDigest), WithCacheDir(cacheDir))
+			assert.NilError(t, err)
+			assert.Equal(t, StatusSkipped, r.Status)
 
-		localPath2 := localPath + "-2"
-		r, err = Download(context.Background(), localPath2, dummyRemoteFileURL, WithExpectedDigest(dummyRemoteFileDigest), WithCacheDir(cacheDir))
-		assert.NilError(t, err)
-		assert.Equal(t, StatusUsedCache, r.Status)
+			localPath2 := localPath + "-2"
+			r, err = Download(context.Background(), localPath2, dummyRemoteFileURL,
+				WithExpectedDigest(dummyRemoteFileDigest), WithCacheDir(cacheDir))
+			assert.NilError(t, err)
+			assert.Equal(t, StatusUsedCache, r.Status)
+		})
+		t.Run("parallel", func(t *testing.T) {
+			cacheDir := filepath.Join(t.TempDir(), "cache")
+			results := make(chan downloadResult, parallelDownloads)
+			for i := 0; i < parallelDownloads; i++ {
+				go func() {
+					// Parallel download is supported only for different instances with unique localPath.
+					localPath := filepath.Join(t.TempDir(), t.Name())
+					r, err := Download(context.Background(), localPath, dummyRemoteFileURL,
+						WithExpectedDigest(dummyRemoteFileDigest), WithCacheDir(cacheDir))
+					results <- downloadResult{r, err}
+				}()
+			}
+			// We must process all results before cleanup.
+			for i := 0; i < parallelDownloads; i++ {
+				result := <-results
+				if result.err != nil {
+					t.Errorf("Download failed: %s", result.err)
+				} else if !slices.Contains(parallelStatus, result.r.Status) {
+					t.Errorf("Expected download status %s, got %s", parallelStatus, result.r.Status)
+				}
+			}
+		})
 	})
 	t.Run("caching-only mode", func(t *testing.T) {
-		_, err := Download(context.Background(), "", dummyRemoteFileURL, WithExpectedDigest(dummyRemoteFileDigest))
-		assert.ErrorContains(t, err, "cache directory to be specified")
+		t.Run("serial", func(t *testing.T) {
+			_, err := Download(context.Background(), "", dummyRemoteFileURL, WithExpectedDigest(dummyRemoteFileDigest))
+			assert.ErrorContains(t, err, "cache directory to be specified")
 
-		cacheDir := filepath.Join(t.TempDir(), "cache")
-		r, err := Download(context.Background(), "", dummyRemoteFileURL, WithExpectedDigest(dummyRemoteFileDigest), WithCacheDir(cacheDir))
-		assert.NilError(t, err)
-		assert.Equal(t, StatusDownloaded, r.Status)
+			cacheDir := filepath.Join(t.TempDir(), "cache")
+			r, err := Download(context.Background(), "", dummyRemoteFileURL, WithExpectedDigest(dummyRemoteFileDigest),
+				WithCacheDir(cacheDir))
+			assert.NilError(t, err)
+			assert.Equal(t, StatusDownloaded, r.Status)
 
-		r, err = Download(context.Background(), "", dummyRemoteFileURL, WithExpectedDigest(dummyRemoteFileDigest), WithCacheDir(cacheDir))
-		assert.NilError(t, err)
-		assert.Equal(t, StatusUsedCache, r.Status)
+			r, err = Download(context.Background(), "", dummyRemoteFileURL, WithExpectedDigest(dummyRemoteFileDigest),
+				WithCacheDir(cacheDir))
+			assert.NilError(t, err)
+			assert.Equal(t, StatusUsedCache, r.Status)
 
-		localPath := filepath.Join(t.TempDir(), t.Name())
-		r, err = Download(context.Background(), localPath, dummyRemoteFileURL, WithExpectedDigest(dummyRemoteFileDigest), WithCacheDir(cacheDir))
-		assert.NilError(t, err)
-		assert.Equal(t, StatusUsedCache, r.Status)
+			localPath := filepath.Join(t.TempDir(), t.Name())
+			r, err = Download(context.Background(), localPath, dummyRemoteFileURL,
+				WithExpectedDigest(dummyRemoteFileDigest), WithCacheDir(cacheDir))
+			assert.NilError(t, err)
+			assert.Equal(t, StatusUsedCache, r.Status)
+		})
+		t.Run("parallel", func(t *testing.T) {
+			cacheDir := filepath.Join(t.TempDir(), "cache")
+			results := make(chan downloadResult, parallelDownloads)
+			for i := 0; i < parallelDownloads; i++ {
+				go func() {
+					r, err := Download(context.Background(), "", dummyRemoteFileURL,
+						WithExpectedDigest(dummyRemoteFileDigest), WithCacheDir(cacheDir))
+					results <- downloadResult{r, err}
+				}()
+			}
+			// We must process all results before cleanup.
+			for i := 0; i < parallelDownloads; i++ {
+				result := <-results
+				if result.err != nil {
+					t.Errorf("Download failed: %s", result.err)
+				} else if !slices.Contains(parallelStatus, result.r.Status) {
+					t.Errorf("Expected download status %s, got %s", parallelStatus, result.r.Status)
+				}
+			}
+		})
 	})
 	t.Run("cached", func(t *testing.T) {
 		_, err := Cached(dummyRemoteFileURL, WithExpectedDigest(dummyRemoteFileDigest))
@@ -121,6 +188,61 @@ func TestDownloadRemote(t *testing.T) {
 	})
 }
 
+func TestRedownloadRemote(t *testing.T) {
+	remoteDir := t.TempDir()
+	ts := httptest.NewServer(http.FileServer(http.Dir(remoteDir)))
+	t.Cleanup(ts.Close)
+
+	downloadDir := t.TempDir()
+
+	cacheOpt := WithCacheDir(t.TempDir())
+
+	t.Run("digest-less", func(t *testing.T) {
+		remoteFile := filepath.Join(remoteDir, "digest-less.txt")
+		assert.NilError(t, os.WriteFile(remoteFile, []byte("digest-less"), 0o644))
+		assert.NilError(t, os.Chtimes(remoteFile, time.Now(), time.Now().Add(-time.Hour)))
+		opt := []Opt{cacheOpt}
+
+		r, err := Download(context.Background(), filepath.Join(downloadDir, "digest-less1.txt"), ts.URL+"/digest-less.txt", opt...)
+		assert.NilError(t, err)
+		assert.Equal(t, StatusDownloaded, r.Status)
+		r, err = Download(context.Background(), filepath.Join(downloadDir, "digest-less2.txt"), ts.URL+"/digest-less.txt", opt...)
+		assert.NilError(t, err)
+		assert.Equal(t, StatusUsedCache, r.Status)
+
+		// modifying remote file will cause redownload
+		assert.NilError(t, os.Chtimes(remoteFile, time.Now(), time.Now()))
+		r, err = Download(context.Background(), filepath.Join(downloadDir, "digest-less3.txt"), ts.URL+"/digest-less.txt", opt...)
+		assert.NilError(t, err)
+		assert.Equal(t, StatusDownloaded, r.Status)
+	})
+
+	t.Run("has-digest", func(t *testing.T) {
+		remoteFile := filepath.Join(remoteDir, "has-digest.txt")
+		bytes := []byte("has-digest")
+		assert.NilError(t, os.WriteFile(remoteFile, bytes, 0o644))
+		assert.NilError(t, os.Chtimes(remoteFile, time.Now(), time.Now().Add(-time.Hour)))
+
+		digester := digest.SHA256.Digester()
+		_, err := digester.Hash().Write(bytes)
+		assert.NilError(t, err)
+		opt := []Opt{cacheOpt, WithExpectedDigest(digester.Digest())}
+
+		r, err := Download(context.Background(), filepath.Join(downloadDir, "has-digest1.txt"), ts.URL+"/has-digest.txt", opt...)
+		assert.NilError(t, err)
+		assert.Equal(t, StatusDownloaded, r.Status)
+		r, err = Download(context.Background(), filepath.Join(downloadDir, "has-digest2.txt"), ts.URL+"/has-digest.txt", opt...)
+		assert.NilError(t, err)
+		assert.Equal(t, StatusUsedCache, r.Status)
+
+		// modifying remote file won't cause redownload because expected digest is provided
+		assert.NilError(t, os.Chtimes(remoteFile, time.Now(), time.Now()))
+		r, err = Download(context.Background(), filepath.Join(downloadDir, "has-digest3.txt"), ts.URL+"/has-digest.txt", opt...)
+		assert.NilError(t, err)
+		assert.Equal(t, StatusUsedCache, r.Status)
+	})
+}
+
 func TestDownloadLocal(t *testing.T) {
 	const emptyFileDigest = "sha256:e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855"
 	const testDownloadLocalDigest = "sha256:0c1e0fba69e8919b306d030bf491e3e0c46cf0a8140ff5d7516ba3a83cbea5b3"
@@ -153,8 +275,6 @@ func TestDownloadLocal(t *testing.T) {
 		r, err := Download(context.Background(), localPath, testLocalFileURL, WithExpectedDigest(testDownloadLocalDigest))
 		assert.NilError(t, err)
 		assert.Equal(t, StatusDownloaded, r.Status)
-
-		os.Remove(localTestFile)
 	})
 
 	t.Run("cached", func(t *testing.T) {
