@@ -5,7 +5,6 @@ import (
 	"fmt"
 	"net"
 
-	"github.com/lima-vm/lima/pkg/limayaml"
 	"github.com/lima-vm/lima/pkg/store"
 )
 
@@ -73,7 +72,6 @@ type Driver interface {
 
 type BaseDriver struct {
 	Instance *store.Instance
-	Yaml     *limayaml.LimaYAML
 
 	SSHLocalPort int
 	VSockPort    int
