@@ -32,14 +32,8 @@ func Delete(ctx context.Context, inst *store.Instance, force bool) error {
 }
 
 func unregister(ctx context.Context, inst *store.Instance) error {
-	y, err := inst.LoadYAML()
-	if err != nil {
-		return err
-	}
-
 	limaDriver := driverutil.CreateTargetDriverInstance(&driver.BaseDriver{
 		Instance: inst,
-		Yaml:     y,
 	})
 
 	return limaDriver.Unregister(ctx)
