@@ -10,11 +10,15 @@ import (
 	"regexp"
 	"runtime"
 	"strings"
+	"unicode"
 
+	"github.com/coreos/go-semver/semver"
 	"github.com/docker/go-units"
 	"github.com/lima-vm/lima/pkg/localpathutil"
 	"github.com/lima-vm/lima/pkg/networks"
 	"github.com/lima-vm/lima/pkg/osutil"
+	"github.com/lima-vm/lima/pkg/version"
+	"github.com/lima-vm/lima/pkg/version/versionutil"
 	"github.com/sirupsen/logrus"
 )
 
@@ -42,6 +46,23 @@ func validateFileObject(f File, fieldName string) error {
 }
 
 func Validate(y *LimaYAML, warn bool) error {
+	if y.MinimumLimaVersion != nil {
+		if _, err := versionutil.Parse(*y.MinimumLimaVersion); err != nil {
+			return fmt.Errorf("field `minimumLimaVersion` must be a semvar value, got %q: %w", *y.MinimumLimaVersion, err)
+		}
+		limaVersion, err := versionutil.Parse(version.Version)
+		if err != nil {
+			return fmt.Errorf("can't parse builtin Lima version %q: %w", version.Version, err)
+		}
+		if versionutil.GreaterThan(*y.MinimumLimaVersion, limaVersion.String()) {
+			return fmt.Errorf("template requires Lima version %q; this is only %q", *y.MinimumLimaVersion, limaVersion.String())
+		}
+	}
+	if y.VMOpts.QEMU.MinimumVersion != nil {
+		if _, err := semver.NewVersion(*y.VMOpts.QEMU.MinimumVersion); err != nil {
+			return fmt.Errorf("field `vmOpts.qemu.minimumVersion` must be a semvar value, got %q: %w", *y.VMOpts.QEMU.MinimumVersion, err)
+		}
+	}
 	switch *y.OS {
 	case LINUX:
 	default:
@@ -80,8 +101,6 @@ func Validate(y *LimaYAML, warn bool) error {
 			if f.Kernel.Arch != f.Arch {
 				return fmt.Errorf("images[%d].kernel has unexpected architecture %q, must be %q", i, f.Kernel.Arch, f.Arch)
 			}
-		} else if f.Arch == RISCV64 {
-			return errors.New("riscv64 needs the kernel (e.g., \"uboot.elf\") to be specified")
 		}
 		if f.Initrd != nil {
 			if err := validateFileObject(*f.Initrd, fmt.Sprintf("images[%d].initrd", i)); err != nil {
@@ -117,13 +136,6 @@ func Validate(y *LimaYAML, warn bool) error {
 		return fmt.Errorf("field `memory` has an invalid value: %w", err)
 	}
 
-	u, err := osutil.LimaUser(false)
-	if err != nil {
-		return fmt.Errorf("internal error (not an error of YAML): %w", err)
-	}
-	// reservedHome is the home directory defined in "cidata.iso:/user-data"
-	reservedHome := fmt.Sprintf("/home/%s.linux", u.Username)
-
 	for i, f := range y.Mounts {
 		if !filepath.IsAbs(f.Location) && !strings.HasPrefix(f.Location, "~") {
 			return fmt.Errorf("field `mounts[%d].location` must be an absolute path, got %q",
@@ -136,8 +148,9 @@ func Validate(y *LimaYAML, warn bool) error {
 		switch loc {
 		case "/", "/bin", "/dev", "/etc", "/home", "/opt", "/sbin", "/tmp", "/usr", "/var":
 			return fmt.Errorf("field `mounts[%d].location` must not be a system path such as /etc or /usr", i)
-		case reservedHome:
-			return fmt.Errorf("field `mounts[%d].location` is internally reserved", i)
+		// home directory defined in "cidata.iso:/user-data"
+		case *y.User.Home:
+			return fmt.Errorf("field `mounts[%d].location` is the reserved internal home directory", i)
 		}
 
 		st, err := os.Stat(loc)
@@ -166,6 +179,12 @@ func Validate(y *LimaYAML, warn bool) error {
 		return fmt.Errorf("field `mountType` must be %q or %q or %q, or %q, got %q", REVSSHFS, NINEP, VIRTIOFS, WSLMount, *y.MountType)
 	}
 
+	for _, f := range y.MountTypesUnsupported {
+		if f == *y.MountType {
+			return fmt.Errorf("field `mountType` must not be one of %v (`mountTypesUnsupported`), got %q", y.MountTypesUnsupported, *y.MountType)
+		}
+	}
+
 	if warn && runtime.GOOS != "linux" {
 		for i, mount := range y.Mounts {
 			if mount.Virtiofs.QueueSize != nil {
@@ -189,20 +208,41 @@ func Validate(y *LimaYAML, warn bool) error {
 			return fmt.Errorf("field `provision[%d].mode` must one of %q, %q, %q, %q, or %q",
 				i, ProvisionModeSystem, ProvisionModeUser, ProvisionModeBoot, ProvisionModeDependency, ProvisionModeAnsible)
 		}
+		if p.Playbook != "" {
+			if p.Mode != ProvisionModeAnsible {
+				return fmt.Errorf("field `provision[%d].mode must be %q if playbook is set", i, ProvisionModeAnsible)
+			}
+			if p.Script != "" {
+				return fmt.Errorf("field `provision[%d].script must be empty if playbook is set", i)
+			}
+			playbook := p.Playbook
+			if _, err := os.Stat(playbook); err != nil {
+				return fmt.Errorf("field `provision[%d].playbook` refers to an inaccessible path: %q: %w", i, playbook, err)
+			}
+		}
 		if strings.Contains(p.Script, "LIMA_CIDATA") {
 			logrus.Warn("provisioning scripts should not reference the LIMA_CIDATA variables")
 		}
 	}
 	needsContainerdArchives := (y.Containerd.User != nil && *y.Containerd.User) || (y.Containerd.System != nil && *y.Containerd.System)
-	if needsContainerdArchives && len(y.Containerd.Archives) == 0 {
-		return fmt.Errorf("field `containerd.archives` must be provided")
+	if needsContainerdArchives {
+		if len(y.Containerd.Archives) == 0 {
+			return fmt.Errorf("field `containerd.archives` must be provided")
+		}
+		for i, f := range y.Containerd.Archives {
+			if err := validateFileObject(f, fmt.Sprintf("containerd.archives[%d]", i)); err != nil {
+				return err
+			}
+		}
 	}
 	for i, p := range y.Probes {
+		if !strings.HasPrefix(p.Script, "#!") {
+			return fmt.Errorf("field `probe[%d].script` must start with a '#!' line", i)
+		}
 		switch p.Mode {
 		case ProbeModeReadiness:
 		default:
-			return fmt.Errorf("field `probe[%d].mode` can only be %q",
-				i, ProbeModeReadiness)
+			return fmt.Errorf("field `probe[%d].mode` can only be %q", i, ProbeModeReadiness)
 		}
 	}
 	for i, rule := range y.PortForwards {
@@ -272,8 +312,10 @@ func Validate(y *LimaYAML, warn bool) error {
 			return fmt.Errorf("field `%s.hostSocket` must be less than UNIX_PATH_MAX=%d characters, but is %d",
 				field, osutil.UnixPathMax, len(rule.HostSocket))
 		}
-		if rule.Proto != TCP {
-			return fmt.Errorf("field `%s.proto` must be %q", field, TCP)
+		switch rule.Proto {
+		case ProtoTCP, ProtoUDP, ProtoAny:
+		default:
+			return fmt.Errorf("field `%s.proto` must be %q, %q, or %q", field, ProtoTCP, ProtoUDP, ProtoAny)
 		}
 		if rule.Reverse && rule.GuestSocket == "" {
 			return fmt.Errorf("field `%s.reverse` must be %t", field, false)
@@ -308,6 +350,21 @@ func Validate(y *LimaYAML, warn bool) error {
 	if warn {
 		warnExperimental(y)
 	}
+
+	// Validate Param settings
+	// Names must start with a letter, followed by any number of letters, digits, or underscores
+	validParamName := regexp.MustCompile(`^[a-zA-Z][a-zA-Z0-9_]*$`)
+	for param, value := range y.Param {
+		if !validParamName.MatchString(param) {
+			return fmt.Errorf("param %q name does not match regex %q", param, validParamName.String())
+		}
+		for _, r := range value {
+			if !unicode.IsPrint(r) && r != '\t' && r != ' ' {
+				return fmt.Errorf("param %q value contains unprintable character %q", param, r)
+			}
+		}
+	}
+
 	return nil
 }
 
@@ -317,14 +374,14 @@ func validateNetwork(y *LimaYAML) error {
 		field := fmt.Sprintf("networks[%d]", i)
 		switch {
 		case nw.Lima != "":
-			config, err := networks.Config()
+			nwCfg, err := networks.LoadConfig()
 			if err != nil {
 				return err
 			}
-			if config.Check(nw.Lima) != nil {
+			if nwCfg.Check(nw.Lima) != nil {
 				return fmt.Errorf("field `%s.lima` references network %q which is not defined in networks.yaml", field, nw.Lima)
 			}
-			usernet, err := config.Usernet(nw.Lima)
+			usernet, err := nwCfg.Usernet(nw.Lima)
 			if err != nil {
 				return err
 			}
@@ -390,7 +447,7 @@ func validateNetwork(y *LimaYAML) error {
 // It should be called before the `y` parameter is passed to FillDefault() that execute template.
 func ValidateParamIsUsed(y *LimaYAML) error {
 	for key := range y.Param {
-		re, err := regexp.Compile(`{{[^}]*\.Param\.` + key + `[^}]*}}`)
+		re, err := regexp.Compile(`{{[^}]*\.Param\.` + key + `[^}]*}}|\bPARAM_` + key + `\b`)
 		if err != nil {
 			return fmt.Errorf("field to compile regexp for key %q: %w", key, err)
 		}
@@ -419,6 +476,16 @@ func ValidateParamIsUsed(y *LimaYAML) error {
 				break
 			}
 		}
+		for _, p := range y.Mounts {
+			if re.MatchString(p.Location) {
+				keyIsUsed = true
+				break
+			}
+			if p.MountPoint != nil && re.MatchString(*p.MountPoint) {
+				keyIsUsed = true
+				break
+			}
+		}
 		if !keyIsUsed {
 			return fmt.Errorf("field `param` key %q is not used in any provision, probe, copyToHost, or portForward", key)
 		}
@@ -441,15 +508,9 @@ func validatePort(field string, port int) error {
 }
 
 func warnExperimental(y *LimaYAML) {
-	if *y.MountType == NINEP {
-		logrus.Warn("`mountType: 9p` is experimental")
-	}
 	if *y.MountType == VIRTIOFS && runtime.GOOS == "linux" {
 		logrus.Warn("`mountType: virtiofs` on Linux is experimental")
 	}
-	if *y.VMType == VZ {
-		logrus.Warn("`vmType: vz` is experimental")
-	}
 	if *y.Arch == RISCV64 {
 		logrus.Warn("`arch: riscv64` is experimental")
 	}
