@@ -38,8 +38,8 @@ func (c *Client) ConfigureDriver(ctx context.Context, driver *driver.BaseDriver)
 	if err != nil {
 		return err
 	}
-	hosts := driver.Yaml.HostResolver.Hosts
-	hosts[fmt.Sprintf("lima-%s.internal", driver.Instance.Name)] = ipAddress
+	hosts := driver.Instance.Config.HostResolver.Hosts
+	hosts[fmt.Sprintf("%s.internal", driver.Instance.Hostname)] = ipAddress
 	err = c.AddDNSHosts(hosts)
 	return err
 }
