@@ -43,9 +43,9 @@ func New(driver *driver.BaseDriver) *LimaQemuDriver {
 }
 
 func (l *LimaQemuDriver) Validate() error {
-	if *l.Yaml.MountType == limayaml.VIRTIOFS && runtime.GOOS != "linux" {
+	if *l.Instance.Config.MountType == limayaml.VIRTIOFS && runtime.GOOS != "linux" {
 		return fmt.Errorf("field `mountType` must be %q or %q for QEMU driver on non-Linux, got %q",
-			limayaml.REVSSHFS, limayaml.NINEP, *l.Yaml.MountType)
+			limayaml.REVSSHFS, limayaml.NINEP, *l.Instance.Config.MountType)
 	}
 	return nil
 }
@@ -54,7 +54,7 @@ func (l *LimaQemuDriver) CreateDisk(ctx context.Context) error {
 	qCfg := Config{
 		Name:        l.Instance.Name,
 		InstanceDir: l.Instance.Dir,
-		LimaYAML:    l.Yaml,
+		LimaYAML:    l.Instance.Config,
 	}
 	return EnsureDisk(ctx, qCfg)
 }
@@ -70,7 +70,7 @@ func (l *LimaQemuDriver) Start(ctx context.Context) (chan error, error) {
 	qCfg := Config{
 		Name:         l.Instance.Name,
 		InstanceDir:  l.Instance.Dir,
-		LimaYAML:     l.Yaml,
+		LimaYAML:     l.Instance.Config,
 		SSHLocalPort: l.SSHLocalPort,
 	}
 	qExe, qArgs, err := Cmdline(ctx, qCfg)
@@ -79,13 +79,13 @@ func (l *LimaQemuDriver) Start(ctx context.Context) (chan error, error) {
 	}
 
 	var vhostCmds []*exec.Cmd
-	if *l.Yaml.MountType == limayaml.VIRTIOFS {
+	if *l.Instance.Config.MountType == limayaml.VIRTIOFS {
 		vhostExe, err := FindVirtiofsd(qExe)
 		if err != nil {
 			return nil, err
 		}
 
-		for i := range l.Yaml.Mounts {
+		for i := range l.Instance.Config.Mounts {
 			args, err := VirtiofsdCmdline(qCfg, i)
 			if err != nil {
 				return nil, err
@@ -189,8 +189,8 @@ func (l *LimaQemuDriver) Start(ctx context.Context) (chan error, error) {
 	}()
 	l.vhostCmds = vhostCmds
 	go func() {
-		if usernetIndex := limayaml.FirstUsernetIndex(l.Yaml); usernetIndex != -1 {
-			client := usernet.NewClientByName(l.Yaml.Networks[usernetIndex].Lima)
+		if usernetIndex := limayaml.FirstUsernetIndex(l.Instance.Config); usernetIndex != -1 {
+			client := usernet.NewClientByName(l.Instance.Config.Networks[usernetIndex].Lima)
 			err := client.ConfigureDriver(ctx, l.BaseDriver)
 			if err != nil {
 				l.qWaitCh <- err
@@ -296,9 +296,10 @@ func (l *LimaQemuDriver) killVhosts() error {
 }
 
 func (l *LimaQemuDriver) shutdownQEMU(ctx context.Context, timeout time.Duration, qCmd *exec.Cmd, qWaitCh <-chan error) error {
-	logrus.Info("Shutting down QEMU with ACPI")
-	if usernetIndex := limayaml.FirstUsernetIndex(l.Yaml); usernetIndex != -1 {
-		client := usernet.NewClientByName(l.Yaml.Networks[usernetIndex].Lima)
+	// "power button" refers to ACPI on the most archs, except RISC-V
+	logrus.Info("Shutting down QEMU with the power button")
+	if usernetIndex := limayaml.FirstUsernetIndex(l.Instance.Config); usernetIndex != -1 {
+		client := usernet.NewClientByName(l.Instance.Config.Networks[usernetIndex].Lima)
 		err := client.UnExposeSSH(l.SSHLocalPort)
 		if err != nil {
 			logrus.Warnf("Failed to remove SSH binding for port %d", l.SSHLocalPort)
@@ -348,7 +349,7 @@ func (l *LimaQemuDriver) killQEMU(_ context.Context, _ time.Duration, qCmd *exec
 	} else {
 		logrus.Info("QEMU has already exited")
 	}
-	qemuPIDPath := filepath.Join(l.Instance.Dir, filenames.PIDFile(*l.Yaml.VMType))
+	qemuPIDPath := filepath.Join(l.Instance.Dir, filenames.PIDFile(*l.Instance.Config.VMType))
 	_ = os.RemoveAll(qemuPIDPath)
 	_ = l.removeVNCFiles()
 	return errors.Join(qWaitErr, l.killVhosts())
@@ -366,7 +367,7 @@ func (l *LimaQemuDriver) DeleteSnapshot(_ context.Context, tag string) error {
 	qCfg := Config{
 		Name:        l.Instance.Name,
 		InstanceDir: l.Instance.Dir,
-		LimaYAML:    l.Yaml,
+		LimaYAML:    l.Instance.Config,
 	}
 	return Del(qCfg, l.Instance.Status == store.StatusRunning, tag)
 }
@@ -375,7 +376,7 @@ func (l *LimaQemuDriver) CreateSnapshot(_ context.Context, tag string) error {
 	qCfg := Config{
 		Name:        l.Instance.Name,
 		InstanceDir: l.Instance.Dir,
-		LimaYAML:    l.Yaml,
+		LimaYAML:    l.Instance.Config,
 	}
 	return Save(qCfg, l.Instance.Status == store.StatusRunning, tag)
 }
@@ -384,7 +385,7 @@ func (l *LimaQemuDriver) ApplySnapshot(_ context.Context, tag string) error {
 	qCfg := Config{
 		Name:        l.Instance.Name,
 		InstanceDir: l.Instance.Dir,
-		LimaYAML:    l.Yaml,
+		LimaYAML:    l.Instance.Config,
 	}
 	return Load(qCfg, l.Instance.Status == store.StatusRunning, tag)
 }
@@ -393,7 +394,7 @@ func (l *LimaQemuDriver) ListSnapshots(_ context.Context) (string, error) {
 	qCfg := Config{
 		Name:        l.Instance.Name,
 		InstanceDir: l.Instance.Dir,
-		LimaYAML:    l.Yaml,
+		LimaYAML:    l.Instance.Config,
 	}
 	return List(qCfg, l.Instance.Status == store.StatusRunning)
 }
