@@ -15,29 +15,27 @@ func FuzzLoadYAMLByFilePath(f *testing.F) {
 		if err != nil {
 			t.Fatal(err)
 		}
-		//nolint:errcheck // The test doesn't check the return value
-		LoadYAMLByFilePath(localFile)
+		_, _ = LoadYAMLByFilePath(localFile)
 	})
 }
 
 func FuzzInspect(f *testing.F) {
 	f.Fuzz(func(t *testing.T, yml, limaVersion []byte) {
 		limaDir := t.TempDir()
-		os.Setenv("LIMA_HOME", limaDir)
+		t.Setenv("LIMA_HOME", limaDir)
 		err := os.MkdirAll(filepath.Join(limaDir, "fuzz-instance"), 0o700)
 		if err != nil {
-			// panic so that we know of problems here
-			panic(err)
+			t.Fatal(err)
 		}
 		ymlFile := filepath.Join(limaDir, "fuzz-instance", filenames.LimaYAML)
 		limaVersionFile := filepath.Join(limaDir, filenames.LimaVersion)
 		err = os.WriteFile(ymlFile, yml, 0o600)
 		if err != nil {
-			return
+			t.Fatal(err)
 		}
 		err = os.WriteFile(limaVersionFile, limaVersion, 0o600)
 		if err != nil {
-			return
+			t.Fatal(err)
 		}
 		_, _ = Inspect("fuzz-instance")
 	})
